function [R, S, iter] = HeatEnrichment (KX, KY, MX, MY, VX, VY, CX, CY, R0, S0, F, G, CCX, CCY, BCX, BCY, TOL, Kconduct, ro, Cp)

iter = 1;       % Initialization of the iteration counter
maxit = 51;     % Maximum number of possible iterations for the fixed point algorithm
error = 1.0e8;  % Initialization of the error value (necessary to start the loop)
R = R0;         % R initialization
S = S0;         % S initialization
R(BCX) = 0;     % Boundary Conditions in 'R'
S(BCY) = 0;     % Boundary Conditions in 'S'

%
% FIXED POINT ALGORITHM
%

while abs(error)>TOL
    Rold = R;               % Update the old value of 'R'
    Sold = S;               % Update the old value of 'S'
    
    SourceR = 0.0;          % Initialice the Source Term of 'R'
    RightTermR = 0.0;       % Initialice the Right Term of 'R'

    %
    % Compute R, assuming S known
    %
    LeftTermR = (ro * Cp) .* (S' * CY * S) .* MX + Kconduct .* (S' * MY * S) .* KX;
        
    for i1=1:size(VX,2)
        SourceR = SourceR + VX(:,i1) * (S' * VY(:,i1));
    end
    
    for i1=1:size(F,2)
        RightTermR = RightTermR + (ro * Cp) .* (MX * F(:,i1) .* (S' * CY * G(:,i1))) + ...
                                    Kconduct .* (KX * F(:,i1) .* (S' * MY * G(:,i1)));
    end
    R(CCX) = LeftTermR(CCX,CCX) \ (SourceR(CCX) - RightTermR(CCX));
    R = R/sqrt(R'*MX*R);

    %
    % Compute S, assuming R known
    %
    LeftTermS = (ro * Cp) .* (R' * MX * R) .* CY + Kconduct .* (R' * KX * R) .* MY;
    
    SourceS = 0.0;          % Initialice the Source Term of 'S'
    RightTermS = 0.0;       % Initialice the Right Term of 'R'
    for i1=1:size(VX,2)
        SourceS = SourceS + VY(:,i1) * R' * VX(:,i1);
    end
    
    for i1=1:size(F,2)
        RightTermS = RightTermS + (ro * Cp) .* (CY * G(:,i1) .* (R' * MX * F(:,i1)) + ...
                                    Kconduct .* (MY *  G(:,i1)) .* (R' * KX * F(:,i1)));
    end
    S(CCY) = LeftTermS(CCY,CCY) \ (SourceS(CCY) - RightTermS(CCY));   
    
    error = sqrt(norm(Rold-R)+norm(Sold-S));
    iter = iter + 1;
    if iter == maxit
        return ;
    end
end
return
