%
% Script made to compute the Discrete Source Term of the Idelsohn's Equation 
% avoiding related problems to the function dependencies.
% 
% 
% Code created by David Gonzalez, 
% Adapted to the Idelsohn's Eq. by Alberto Badias.
%
% Applied Mechanics and Bioengineering.
% Universidad de Zaragoza.
%
% START:      22 Abril 2016
% LAST MODIF: 22 ABRIL 2016
%

function [FR1,FR2] = OwnFuenteDiscreta(coor1,coor2,TOL, fuente)
nn1 = numel(coor1); nn2 = numel(coor2);
[xx, yy] = meshgrid(coor1, coor2); 

[ff1,dd,ff2]= svd(fuente);
dd = diag(dd); 
nf = sum(dd/dd(1) >= TOL); % Desired tolerance!!
if nf==0
    nf = 1;
end
dd  = dd(1:nf);
ss  = sign(sum(ff1(:,1)));
FR1 = ss * meshgrid(sqrt(dd),ones(nn1,1)) .* ff1(:,1:nf);
FR2 = ss * meshgrid(sqrt(dd),ones(nn2,1)) .* ff2(:,1:nf);

figure , surf(xx,yy,fuente','EdgeColor','none') , title ('Source original function')
xlabel('Space'); ylabel('Time');
axisLim = axis;
figure , surf(xx,yy,FR2*FR1','EdgeColor','none') , title ('Source approximation')
xlabel('Space'); ylabel('Time');
axis(axisLim);
return
